@@ -151,15 +151,16 @@ class EnterpriseSubsidyAPIClient:
         response.raise_for_status()
         return response.json()
 
-    def create_subsidy_transaction(self, subsidy_uuid, lms_user_id, content_key, subsidy_access_policy_uuid):
+    def create_subsidy_transaction(self, subsidy_uuid, lms_user_id, content_key, subsidy_access_policy_uuid, metadata):
         """
         TODO: add docstring.
         """
         request_payload = {
             'subsidy_uuid': str(subsidy_uuid),
-            'learner_id': lms_user_id,
+            'lms_user_id': lms_user_id,
             'content_key': content_key,
             'subsidy_access_policy_uuid': str(subsidy_access_policy_uuid),
+            'metadata': metadata,
         }
         response = self.client.post(
             self.TRANSACTIONS_ENDPOINT,
